@@ -3,8 +3,8 @@ import argparse
 from .scan_runner import ScanRunner
 from .utils import Utils
 
-LANGUAGES = ['ruby', 'javascript', 'typescript', 'python', 'php',
-             'java', 'license', 'go', 'python2']
+LANGUAGES = ['ruby', 'javascript', 'typescript', 'python2', 'python3', 'python', 'php',
+             'java', 'license', 'go']
 SCANNERS = ['sast', 'dast', 'sca', 'secrets']
 BUILD_TOOLS = ['jenkins', 'travis']
 
@@ -68,9 +68,16 @@ def parse_command_line_params():
     }
 
     if command_args.scanner is not None:
-        command_line_params['scanner'] = ','.join(command_args.scanner)
+        command_line_params['scanner'] = ','.join(Utils.remove_duplicated_items_list(command_args.scanner))
     if command_args.lang is not None:
-        command_line_params['language'] = command_args.lang
+        languages = []
+        for language in command_args.lang:
+            if language == 'python3':
+                language = 'python'
+
+            languages.append(language)
+
+        command_line_params['language'] = Utils.remove_duplicated_items_list(languages)
 
     return command_line_params, command_args
 
@@ -106,19 +113,22 @@ def check_language(command_line_params, yaml_config):
         languages = yaml_config['language'].split(',')
         for language in languages:
             if language in LANGUAGES:
+                if language == 'python3':
+                    language = 'python'
+
                 yaml_language.append(language)
             else:
                 print("Scanner for %s hasn't been supported." % language)
 
     if len(yaml_language) > 0:
-        yaml_config['language'] = yaml_language
+        yaml_config['language'] = Utils.remove_duplicated_items_list(yaml_language)
     elif 'language' in yaml_config:
         del yaml_config['language']
 
     return 'language' in yaml_config or 'language' in command_line_params
 
 def version():
-    return '0.1.58'
+    return '0.1.61'
 
 def main():
     command_line_params, command_args = parse_command_line_params()
