@@ -80,13 +80,19 @@ class Utils(object):
 
 		ecr_client = session.client('ecr')
 		token = ecr_client.get_authorization_token()
+		print("ECR auth token: " + token['authorizationData'][0]['authorizationToken'])
 		ecr_username, ecr_password = base64.b64decode(token['authorizationData'][0]['authorizationToken']).decode().split(':')
+		print("ecr user: " + ecr_username)
+		print("ecr pwd: " + ecr_password)
 		registry = token['authorizationData'][0]['proxyEndpoint']
 
 		command = ['docker', 'login', '-u', ecr_username, '--password-stdin', registry]
 		if sys.version_info < (3, 0):
 			command = ['docker login -u ' + ecr_username + ' --password-stdin ' + registry]
 
+		print("Python version: " + str(sys.version_info.major) + "." + str(sys.version_info.minor))
+		print("docker login command: " + " ".join(command))
+
 		p = subprocess.Popen(command, stdout=subprocess.PIPE, stderr=subprocess.STDOUT, stdin=subprocess.PIPE, shell=True)
 		stdout, stderr = p.communicate(input=ecr_password.encode('utf-8'))
 		p.wait()
@@ -224,7 +230,7 @@ class Utils(object):
 		try:
 			client = cls.docker_login(scan_info)
 			cls.docker_pull_image(client, cls.cloc_image)
-			command_line = '/scan --json --out /scan/sken-cloc.json'
+			command_line = "/scan --json --out /scan/sken-cloc.json  --exclude-dir node_modules,target,dist,build,node --skip-archive '(zip|tar|jar|war(.(gz|Z|bz2|xz|7z))?)' --exclude-ext json,xml,svg,md"
 			container = client.containers.run(cls.cloc_image, command_line, volumes={build_dir: {
 				'bind': '/scan', 'mode': 'rw'}}, detach=True, tty=False, stdout=True, stderr=True)
 			container.wait()
@@ -444,3 +450,10 @@ class Utils(object):
 				pass
 
 		return timestamp
+
+	@classmethod
+	def remove_duplicated_items_list(cls, list_object):
+		if list_object is None:
+			return []
+
+		return list(dict.fromkeys(list_object))
